package Class::PObject::Type::CHAR;

# $Id: CHAR.pm,v 1.1.2.4 2003/09/06 14:00:51 sherzodr Exp $

use strict;
#use diagnostics;
use vars ('$VERSION', '@ISA');
use Class::PObject::Type;
use overload (
    '""' => sub { $_[0]->id },
    bool => sub { $_[0]->id ? 1 : 0 },
    fallback => 1,
);


@ISA = ("Class::PObject::Type");
$VERSION = '1.00';





1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

Class::PObject::Type::CHAR - Defines CHAR column type

=head1 DESCRIPTION

ISA L<Class::PObject::Type|Class::PObject::Type>

=head1 COPYRIGHT AND LICENSE

For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.

=cut
